==> ToolChain_STM32_1.0.38.tar.bz: ToolChain_STM32_1.0.38/CommonLibraries/ttc_usart.c <==
/*{ ttc_usart::.c ************************************************
 
                      The ToolChain
                      
   Device independent support for 
   Universal Synchronous Asynchronous Receiver and Transmitters (USARTs)
   
   written by Gregor Rebel 2012
   
 
}*/

#include "ttc_usart.h"

//{ Function definitions *************************************************

inline                  u8_t ttc_getMax_USART_Index() {

#ifdef TARGET_ARCHITECTURE_STM32
    return stm32_getMax_USART_Index();
#endif

    return 0;
}
inline ttc_usart_errorcode_e ttc_getUSART_Defaults(u8_t USART_Index, ttc_usart_generic_t* USART_Generic) {
    memset(USART_Generic, 0, sizeof(USART_Generic));
    
#ifdef TARGET_ARCHITECTURE_STM32
    return stm32_getUSART_Defaults(USART_Index, USART_Generic);
#endif

  return tue_DeviceNotFound;  
}
inline ttc_usart_errorcode_e ttc_getUSART_Features(u8_t USART_Index, ttc_usart_generic_t* USART_Generic) {
    memset(USART_Generic, 0, sizeof(USART_Generic));
    
#ifdef TARGET_ARCHITECTURE_STM32
    return stm32_getUSART_Features(USART_Index, USART_Generic);
#endif

  return tue_DeviceNotFound;
}
inline ttc_usart_errorcode_e ttc_initUSART(u8_t USART_Index, ttc_usart_generic_t* USART_Generic, ttc_usart_architecture_u* USART_Arch) {
    memset(USART_Arch, 0, sizeof(USART_Arch));

#ifdef TARGET_ARCHITECTURE_STM32
  return stm32_initUSART(USART_Index, USART_Generic, (stm32_usart_architecture_t*) USART_Arch);
#endif

  return tue_DeviceNotFound;
}
inline ttc_usart_errorcode_e ttc_sendRaw(u8_t USART_Index, const char* Buffer, u16_t Amount) {
  
#ifdef TARGET_ARCHITECTURE_STM32
  return stm32_sendRaw(USART_Index, Buffer, Amount);
#endif

  return tue_DeviceNotFound;
}
inline ttc_usart_errorcode_e ttc_sendASCII(u8_t USART_Index, const char* Buffer, u16_t MaxLength) {
  
#ifdef TARGET_ARCHITECTURE_STM32
  return stm32_sendASCII(USART_Index, Buffer, MaxLength);
#endif

  return tue_DeviceNotFound;
}
inline ttc_usart_errorcode_e ttc_sendWord(u8_t USART_Index, const u16_t Word) {

#ifdef TARGET_ARCHITECTURE_STM32
  return stm32_sendWord(USART_Index, Word);
#endif

  return tue_DeviceNotFound;
}
inline ttc_usart_errorcode_e ttc_readWord(u8_t USART_Index, u16_t* Word, u32_t TimeOut) {

#ifdef TARGET_ARCHITECTURE_STM32
  return stm32_readWord(USART_Index, Word, TimeOut);
#endif

  return tue_DeviceNotFound;
}
inline ttc_usart_errorcode_e ttc_readByte(u8_t USART_Index, char* Byte, u32_t TimeOut) {

#ifdef TARGET_ARCHITECTURE_STM32
  return stm32_readByte(USART_Index, Byte, TimeOut);
#endif

  return tue_DeviceNotFound;
}

//} Function definitions

==> ToolChain_STM32_1.0.42.tar.bz: ToolChain_STM32_1.0.42/CommonLibraries/ttc_usart.c <==
/*{ ttc_usart::.c ************************************************
 
                      The ToolChain
                      
   Device independent support for 
   Universal Synchronous Asynchronous Receiver and Transmitters (USARTs)
   
   written by Gregor Rebel 2012
   
 
}*/

#include "ttc_usart.h"

//{ Function definitions *************************************************

inline                  u8_t ttc_getMax_USART_Index() {

    return TTC_AMOUNT_USARTS;
}
inline ttc_usart_errorcode_e ttc_getUSART_Defaults(u8_t USART_Index, ttc_usart_generic_t* USART_Generic) {
    memset(USART_Generic, 0, sizeof(USART_Generic));
    
#ifdef TARGET_ARCHITECTURE_STM32
    return stm32_getUSART_Defaults(USART_Index, USART_Generic);
#endif

  return tue_DeviceNotFound;  
}
inline ttc_usart_errorcode_e ttc_getUSART_Features(u8_t USART_Index, ttc_usart_generic_t* USART_Generic) {
    memset(USART_Generic, 0, sizeof(USART_Generic));
    
#ifdef TARGET_ARCHITECTURE_STM32
    return stm32_getUSART_Features(USART_Index, USART_Generic);
#endif

  return tue_DeviceNotFound;
}
inline ttc_usart_errorcode_e ttc_initUSART(u8_t USART_Index, ttc_usart_generic_t* USART_Generic, ttc_usart_architecture_u* USART_Arch) {
    memset(USART_Arch, 0, sizeof(USART_Arch));

#ifdef TARGET_ARCHITECTURE_STM32
  return stm32_initUSART(USART_Index, USART_Generic, (stm32_usart_architecture_t*) USART_Arch);
#endif

  return tue_DeviceNotFound;
}
inline ttc_usart_errorcode_e ttc_sendRaw(u8_t USART_Index, const char* Buffer, u16_t Amount) {
  
#ifdef TARGET_ARCHITECTURE_STM32
  return stm32_usart_sendBytes(USART_Index, Buffer, Amount);
#endif

  return tue_DeviceNotFound;
}
inline ttc_usart_errorcode_e ttc_sendASCII(u8_t USART_Index, const char* Buffer, u16_t MaxLength) {
  
#ifdef TARGET_ARCHITECTURE_STM32
  return stm32_usart_sendASCII(USART_Index, Buffer, MaxLength);
#endif

  return tue_DeviceNotFound;
}
inline ttc_usart_errorcode_e ttc_sendWord(u8_t USART_Index, const u16_t Word) {

#ifdef TARGET_ARCHITECTURE_STM32
  return stm32_usart_sendWord(USART_Index, Word);
#endif

  return tue_DeviceNotFound;
}
inline ttc_usart_errorcode_e ttc_readWord(u8_t USART_Index, u16_t* Word, u32_t TimeOut) {

#ifdef TARGET_ARCHITECTURE_STM32
  return stm32_usart_readWord(USART_Index, Word, TimeOut);
#endif

  return tue_DeviceNotFound;
}
inline ttc_usart_errorcode_e ttc_readByte(u8_t USART_Index, char* Byte, u32_t TimeOut) {

#ifdef TARGET_ARCHITECTURE_STM32
  return stm32_usart_readByte(USART_Index, Byte, TimeOut);
#endif

  return tue_DeviceNotFound;
}

//} Function definitions
